@@ -1,10 +1,20 @@
 from .bert_model import CirillaBERT, BertArgs
-from .dataloader import JSONLDataset
+from .dataloader import JSONLDataset, GenericDataset
 from .model import Cirilla, Args
-from .modules import benchmark_model_part, load_balancing_loss
+from .modules import benchmark_model_part, load_balancing_loss, CirillaBaseModel
 from .tokenizer_modules import CirillaTokenizer
 from .training import TrainingArgs, CirillaTrainer
-from .blocks import Encoder, EncoderArgs, Decoder, DecoderArgs, MLPMixer1D, MixerArgs
+from .blocks import (
+                    Encoder,
+                    EncoderArgs,
+                    Decoder,
+                    DecoderArgs,
+                    MLPMixer1D,
+                    MixerArgs,
+                    VisionEmbeddingModel,
+                    KeylessAttention,
+                    InputEmbeddings
+                    )
 from .trm import CirillaTRM, TRMArgs
 
 __all__ = [
@@ -13,15 +23,20 @@ __all__ = [
             'Cirilla',
             'Args',
             'JSONLDataset',
+            'GenericDataset',
             'CirillaTokenizer',
             'TrainingArgs',
             'CirillaTrainer',
             'benchmark_model_part',
             'load_balancing_loss',
+            'CirillaBaseModel',
             'Encoder',
             'EncoderArgs',
             'Decoder',
             'DecoderArgs',
+            'InputEmbeddings',
+            'VisionEmbeddingModel',
+            'KeylessAttention',
             'CirillaTRM',
             'TRMArgs',
             'MLPMixer1D',
