@@ -2,7 +2,7 @@ from ..LLM_pieces import (
     RoPE,
     SMoE,
     get_activation,
-    Expert,
+    SwiGLU,
     MegablockMoE,
     MegablockdMoE,
     BertAttention,
@@ -18,6 +18,7 @@ import torch.nn as nn
 from typing import Optional
 import warnings
 import torch
+import torch.nn.functional as F
 from torchao.float8 import convert_to_float8_training, Float8LinearConfig
 from torchao.sparsity.training import (
     SemiSparseLinear,
@@ -52,6 +53,7 @@ class EncoderArgs:
     use_sparse:bool = False
     theta:float = 10_000.0
     device:str = select_torch_device()
+    torch_compile:bool=True
 
     @property
     def dtype(self):
@@ -125,13 +127,16 @@ class Encoder(nn.Module):
             for attention in self.attentions:
                 swap_linear_with_semi_sparse_linear(attention, get_sparse_config(attention))
         
-        self.attentions = nn.ModuleList([
-            torch.compile(attention, mode='max-autotune') for attention in self.attentions
-            ])
+        if self.args.torch_compile:
+            self.attentions = nn.ModuleList([
+                torch.compile(attention, mode='max-autotune') for attention in self.attentions
+                ])
+        else:
+            self.attentions = nn.ModuleList(self.attentions)
         
         if self.args.moe_type == 'pytorch':
             self.smoes = [
-                SMoE(self.args, [Expert(self.args) for _ in range(self.args.num_experts)])
+                SMoE(self.args, [SwiGLU(self.args) for _ in range(self.args.num_experts)])
                 for _ in range(self.args.n_layers)
             ]
 
@@ -142,9 +147,12 @@ class Encoder(nn.Module):
                 for smoe in self.smoes:
                     swap_linear_with_semi_sparse_linear(smoe, get_sparse_config(smoe)) 
 
-            self.smoes = nn.ModuleList([
-                torch.compile(smoe, mode='max-autotune') for smoe in self.smoes
-            ])
+            if self.args.torch_compile:
+                self.smoes = nn.ModuleList([
+                    torch.compile(smoe, mode='max-autotune') for smoe in self.smoes
+                ])
+            else:
+                self.smoes = nn.ModuleList(self.smoes)
 
         elif self.args.moe_type == 'megablocks-moe':
             self.smoes = nn.ModuleList([
@@ -194,7 +202,6 @@ class Encoder(nn.Module):
 @dataclass
 class DecoderArgs:
     """general"""
-    vocab_size:int = 60_000
     dim:int = 1024
     d_ff:int = 2048
     n_layers:int = 16
@@ -222,6 +229,7 @@ class DecoderArgs:
     use_sparse:bool = False
     theta:float = 10_000.0
     device = select_torch_device()
+    torch_compile:bool=True
 
     @property
     def dtype(self):
@@ -239,15 +247,6 @@ class DecoderArgs:
         if self.output_moe_weights:
             assert self.moe_type == "pytorch"
 
-class InputEmbeddings(nn.Module):
-    def __init__(self, args:DecoderArgs):
-        super().__init__()
-
-        self.embeddings = nn.Embedding(args.vocab_size, args.dim)
-    
-    def forward(self, x):
-        return self.embeddings(x)
-
 class Decoder(nn.Module):
 
     def __init__(self, args:DecoderArgs=None):
@@ -315,13 +314,16 @@ class Decoder(nn.Module):
             for attention in self.attentions:
                 swap_linear_with_semi_sparse_linear(attention, get_sparse_config(attention))
 
-        self.attentions = nn.ModuleList([
-            torch.compile(attention, mode='max-autotune') for attention in self.attentions
-            ])
+        if self.args.torch_compile:
+            self.attentions = nn.ModuleList([
+                torch.compile(attention, mode='max-autotune') for attention in self.attentions
+                ])
+        else:
+            self.attentions = nn.ModuleList(self.attentions)
         
         if self.args.moe_type == 'pytorch':
             self.smoes = [
-                SMoE(self.args, [Expert(self.args) for _ in range(self.args.num_experts)])
+                SMoE(self.args, [SwiGLU(self.args) for _ in range(self.args.num_experts)])
                 for _ in range(self.args.n_layers)
             ]
 
@@ -332,9 +334,12 @@ class Decoder(nn.Module):
                 for smoe in self.smoes:
                     swap_linear_with_semi_sparse_linear(smoe, get_sparse_config(smoe))        
 
-            self.smoes = nn.ModuleList([
-                torch.compile(smoe, mode='max-autotune') for smoe in self.smoes
-            ])
+            if self.args.torch_compile:
+                self.smoes = nn.ModuleList([
+                    torch.compile(smoe, mode='max-autotune') for smoe in self.smoes
+                ])
+            else:
+                self.smoes = nn.ModuleList(self.smoes)
 
         elif self.args.moe_type == 'megablocks-moe':
             self.smoes = nn.ModuleList([
@@ -474,3 +479,72 @@ class FeedForward(nn.Module):
     def forward(self, x):
         x = self.net(x)
         return x
+
+class PatchEmbed(nn.Module):
+    def __init__(self, in_ch=3, embed_dim=768, patch_size=16):
+        super().__init__()
+        self.patch_size = patch_size
+        self.proj = nn.Conv2d(in_ch, embed_dim, kernel_size=patch_size, stride=patch_size)
+        self.norm = nn.LayerNorm(embed_dim)
+
+    def forward(self, x):
+        # x ~ (B, C, H, W)
+        x = self.proj(x)  # (B, D, H/ps, W/ps)
+        x = x.flatten(2).transpose(1, 2)  # (B, H/ps * W/ps, D)
+        x = self.norm(x)
+        return x
+
+class VisionEmbeddingModel(nn.Module):
+    def __init__(self,
+                    in_ch=3,
+                    embed_dim=768,
+                    patch_size=16,
+                    H=16,
+                    W=16
+                    ):
+        super().__init__()
+        self.patch_embed = PatchEmbed(in_ch=in_ch, embed_dim=embed_dim, patch_size=patch_size)
+        self.token_norm = nn.LayerNorm(embed_dim)
+        self.pos_embed = self._make_pos_embed((H, W), embed_dim)
+
+    def _make_pos_embed(self, grid_hw, embed_dim):
+        H, W = grid_hw
+        pe = nn.Parameter(torch.zeros(1, H * W, embed_dim))
+        nn.init.trunc_normal_(pe, std=0.02)
+        return pe
+
+    def forward(self, x):
+        # x ~ (B, C, H, W)
+        tokens = self.patch_embed(x)  # (B, N, D)
+
+        tokens = tokens + self.pos_embed
+        tokens = self.token_norm(tokens)
+
+        return tokens
+
+class KeylessAttention(nn.Module):
+    def __init__(self, dim):
+        super().__init__()
+        self.wi = nn.Linear(dim, 1, bias=False)
+        self.wt = nn.Linear(dim, 1, bias=False)
+
+    def forward(self, cls_image, cls_text):
+        ei = self.wi(cls_image)
+        et = self.wt(cls_text)
+        lmb = F.sigmoid(ei - et)
+
+        return lmb * cls_image + ((1 - lmb) * cls_text)
+
+@dataclass
+class EmbedArgs:
+    vocab_size: int
+    dim: int
+
+class InputEmbeddings(nn.Module):
+    def __init__(self, args: EmbedArgs):
+        super().__init__()
+
+        self.embeddings = nn.Embedding(args.vocab_size, args.dim)
+    
+    def forward(self, x):
+        return self.embeddings(x)
\ No newline at end of file
