@@ -14,7 +14,7 @@ KEYBOARD_NEIGHBORS = {
     'v': 'cb', 'w': 'qe', 'x': 'zc', 'y': 'tu', 'z': 'x'
     }
 
-class JSONLDataset(IterableDataset):
+class GenericDataset:
     def __init__(self, path:Union[Path, tuple[Path]]='./training_dataset.jsonl',
                 shuffle_path=False,
                 device:torch.device='cuda',
@@ -24,18 +24,19 @@ class JSONLDataset(IterableDataset):
                 eos_token:str='<eos>',
                 sos_token:str='<sos>',
                 user_token:str='<|user|>',
-                bert_append_tokens:list[str]=None, #['<cls>']
+                suffix_tokens:list[str]=None, #['<cls>']
+                prefix_tokens:list[str]=None,
                 random_spelling_mistake_prob:float=0.,
                 random_missing_char_prob:float=0.
                 ):
         
-        super().__init__()
         self.path = path
         self.shuffle_path = shuffle_path
         self.device = device
         self.tokenizer = tokenizer
         self.max_len = max_len
-        self.bert_append_tokens = bert_append_tokens
+        self.suffix_tokens = suffix_tokens
+        self.prefix_tokens = prefix_tokens
         self.random_spelling_mistake_prob = random_spelling_mistake_prob
         self.random_missing_char_prob = random_missing_char_prob
 
@@ -97,6 +98,10 @@ class JSONLDataset(IterableDataset):
             else:
                 new_text.append(letter)
         return ''.join(new_text)
+
+class JSONLDataset(IterableDataset, GenericDataset):
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
     
     def __iter__(self):
 
@@ -126,7 +131,7 @@ class JSONLDataset(IterableDataset):
                                     
                                     out_tokens = out_tokens.to(self.device)
                                     
-                                    line['text'] = self.tokenizer._apply_random_spelling_mistake(line['text'])
+                                    line['text'] = self._apply_random_spelling_mistake(line['text'])
                                     
                                     tokenized_data =  self.tokenizer(self.sos_token + line['text'], return_tensors='pt', padding='do_not_pad',
                                                                     truncation=True, max_length=self.max_len+1)
@@ -145,7 +150,7 @@ class JSONLDataset(IterableDataset):
                                 else:
 
                                     if self.random_spelling_mistake_prob > 0. or self.random_missing_char_prob > 0.:
-                                        line['text'] = self.tokenizer._apply_random_spelling_mistake(line['text'])
+                                        line['text'] = self._apply_random_spelling_mistake(line['text'])
                                         
                                     tokenized_data =  self.tokenizer(self.sos_token + line['text'], return_tensors='pt', padding='do_not_pad',
                                                                     truncation=True, max_length=self.max_len+1)
@@ -192,10 +197,12 @@ class JSONLDataset(IterableDataset):
 
                             if self.tokenizer is not None:
                                 text = line['text']
+                                
+                                if self.prefix_tokens is not None:
+                                    text = "".join(self.prefix_tokens) + text
 
-                                if self.bert_append_tokens is not None:
-                                    for token in self.bert_append_tokens:
-                                        text += token
+                                if self.suffix_tokens is not None:
+                                    text += "".join(self.suffix_tokens)
 
                                 tokenized_data =  self.tokenizer(text, return_tensors='pt', padding='max_length',
                                                                 truncation=True, max_length=self.max_len)
