@@ -1,5 +1,5 @@
 from .activations import get_activation
-from .SMoE import SMoE, Expert, MegablockMoE, MegablockdMoE
+from .SMoE import SMoE, SwiGLU, MegablockMoE, MegablockdMoE
 from .RoPE import RoPE
 from .sliding_window_attention import (
                                     SlidingWindowAttention,
@@ -12,7 +12,7 @@ from .BERT_attention import BertAttention
 __all__ = [
     'get_activation',
     'SMoE',
-    'Expert',
+    'SwiGLU',
     'MegablockMoE',
     'MegablockdMoE',
     'RoPE',
